@@ -1,7 +1,9 @@
+import logging
 import shutil
 import subprocess
 from pathlib import Path
-from typing import Dict, List
+
+from dirsync import sync
 
 from ops2deb import logger
 from ops2deb.apt import DebianRepositoryPackage, sync_list_repository_packages
@@ -19,7 +21,9 @@ def _format_command_output(output: str) -> str:
 
 
 class SourcePackage:
-    def __init__(self, blueprint: Blueprint, output_directory: Path):
+    def __init__(
+        self, blueprint: Blueprint, output_directory: Path, configuration_directory: Path
+    ):
         epoch = f"{blueprint.epoch}:" if blueprint.epoch else ""
         self.debian_version = f"{epoch}{blueprint.version}-{blueprint.revision}~ops2deb"
         self.directory_name = f"{blueprint.name}_{blueprint.version}_{blueprint.arch}"
@@ -29,6 +33,7 @@ class SourcePackage:
         self.fetch_directory = self.package_directory / "fetched"
         self.blueprint = blueprint
         self.remote_file = self.blueprint.render_fetch()
+        self.configuration_directory = configuration_directory
 
     def _render_template(self, template_name: str) -> None:
         template = environment.get_template(f"{template_name}")
@@ -50,17 +55,27 @@ class SourcePackage:
             self.fetch_directory.mkdir(exist_ok=True)
             shutil.copy2(fetch_result.storage_path, self.fetch_directory)
         else:
-            shutil.copytree(fetch_result.storage_path, self.fetch_directory)
+            dirsync_logger = logging.getLogger("dirsync")
+            dirsync_logger.setLevel(logging.CRITICAL)
+            # FIXME: is there a more recent lib to sync trees?
+            #  shutil.copytree is not an option: https://bugs.python.org/issue38523
+            sync(
+                str(fetch_result.storage_path),
+                str(self.fetch_directory),
+                "sync",
+                create=True,
+                logger=dirsync_logger,
+            )
 
     def _install_here_document(self, entry: HereDocument, destination: Path) -> None:
         if destination.exists():
             raise Ops2debGeneratorError(f"Destination {destination} already exists")
-        destination.write_text(self.blueprint.render_string(entry.content))
+        destination.write_text(self._render_string(entry.content))
 
     def _install_source_destination_str(
         self, entry: SourceDestinationStr, destination: Path
     ) -> None:
-        source = Path(self.blueprint.render_string(entry.source))
+        source = Path(self._render_string(entry.source))
         if source.exists() is False:
             raise Ops2debGeneratorError(f"Source {str(source)} does not exist")
         if source.is_dir() is True:
@@ -77,6 +92,7 @@ class SourcePackage:
             string,
             src=self.source_directory,
             debian=self.debian_directory,
+            cwd=self.configuration_directory,
         )
 
     def _install_files(self) -> None:
@@ -108,7 +124,7 @@ class SourcePackage:
             if result.returncode:
                 raise Ops2debGeneratorScriptError
 
-    def generate(self, fetch_results: Dict[str, FetchResult]) -> None:
+    def generate(self, fetch_results: dict[str, FetchResult]) -> None:
         fetch_result: FetchResult | None = None
         if self.remote_file is not None:
             fetch_result = fetch_results.get(self.remote_file.url, None)
@@ -148,10 +164,10 @@ class SourcePackage:
 
 
 def filter_already_published_packages(
-    packages: List[SourcePackage], debian_repository: str
-) -> List[SourcePackage]:
+    packages: list[SourcePackage], debian_repository: str
+) -> list[SourcePackage]:
     already_published_packages = sync_list_repository_packages(debian_repository)
-    filtered_packages: List[SourcePackage] = []
+    filtered_packages: list[SourcePackage] = []
     for package in packages:
         if (
             DebianRepositoryPackage(
@@ -164,13 +180,17 @@ def filter_already_published_packages(
 
 
 def generate(
-    blueprints: List[Blueprint],
+    blueprints: list[Blueprint],
     output_directory: Path,
+    configuration_directory: Path,
     debian_repository: str | None = None,
-    only_names: List[str] | None = None,
-) -> List[SourcePackage]:
+    only_names: list[str] | None = None,
+) -> list[SourcePackage]:
     # each blueprint can yield multiple source packages, one per supported arch
-    packages = [SourcePackage(b, output_directory) for b in extend(blueprints)]
+    packages = [
+        SourcePackage(b, output_directory, configuration_directory)
+        for b in extend(blueprints)
+    ]
 
     if only_names is not None:
         packages = [p for p in packages if p.blueprint.name in only_names]
